@@ -1,3 +1,18 @@
+#' dist
+#'
+#' A simple measure of the chords distances in the circle
+#' of fifths.
+#'
+#' @format A data frame with 3 variables:
+#' \describe{
+#'   \item{\code{prox}}{factor. The chord.}
+#'   \item{\code{dist}}{numeric. The distance from C in the
+#'   circle of fifths. }
+#'   \item{\code{order}}{integer. The order in the circle of
+#'   fifths.}
+#' }
+"dist"
+
 #' all
 #'
 #' All data available.
